@@ -16,6 +16,8 @@ from fhir_cli import (
     FUNCTIONS_DIR_NAME,
     INIT_DB_TEMPLATE,
     JINJA_ENV,
+    OMOP_DBT_SCHEMA,
+    OMOP_TEMPLATES,
     POSTGRES_DB,
     POSTGRES_HOST,
     POSTGRES_PASSWORD,
@@ -81,22 +83,27 @@ class Admin:
 
         stmt = sql.SQL("CREATE DATABASE {database}").format(database=sql.Identifier(database))
 
-        with conn.cursor() as curs:
-            curs.execute(stmt)
-
-        conn.close()
+        try:
+            with conn.cursor() as curs:
+                curs.execute(stmt)
+        except Exception as e:
+            log.error(e)
+        finally:
+            conn.close()
 
     @staticmethod
     def initdb(database: str, url: str, user: str = None, password: str = None):
         """Initialize the new db for the project
 
+        The omop vocabulary tables are populated during this process. It may take some time.
+
         Args:
             database (str): the database to initialize
-            url (str): the source database JDBC url (formatted
-            as jdbc:database_type//host:port/dbname) used to generate the project id
+            url (str): the source database JDBC url (formatted \
+as jdbc:database_type//host:port/dbname) used to generate the project id
             user (:obj:`str`, optional): a username of choice.
-            password (:obj:`str`, optional): a password of choice. If not specified,
-            the command will prompt for a password
+            password (:obj:`str`, optional): a password of choice. If not specified, \
+the command will prompt for a password
         """
 
         try:
@@ -129,21 +136,28 @@ class Admin:
             project_url=url,
         )
 
-        with conn.cursor() as curs:
-            curs.execute(user_stmt, (password,))
-            curs.execute(initdb_stmt)
-            set_search_path_stmt = sql.SQL("SET search_path TO {dbt_schema}").format(
-                dbt_schema=sql.Identifier(DBT_SCHEMA)
-            )
-            curs.execute(set_search_path_stmt)
-            try:
-                for func_definition in get_user_defined_functions():
-                    curs.execute(func_definition)
-                conn.commit()
-            except FileNotFoundError as e:
-                conn.rollback()
-                log.error(e)
-        conn.close()
+        try:
+            with conn:
+                with conn.cursor() as curs:
+                    log.info("Creating a new user...")
+                    curs.execute(user_stmt, (password,))
+                    log.info("Initializing the project database...")
+                    curs.execute(initdb_stmt)
+                    log.info("Loading OMOP vocabulary tables...")
+                    for template in OMOP_TEMPLATES:
+                        omop_stmt = JINJA_ENV.get_template(template).render(schema=OMOP_DBT_SCHEMA)
+                        curs.execute(omop_stmt)
+                    set_search_path_stmt = sql.SQL("SET search_path TO {dbt_schema}").format(
+                        dbt_schema=sql.Identifier(DBT_SCHEMA)
+                    )
+                    curs.execute(set_search_path_stmt)
+                    log.info("Loading user defined functions...")
+                    for func_definition in get_user_defined_functions():
+                        curs.execute(func_definition)
+        except Exception as e:
+            log.error(e)
+        finally:
+            conn.close()
 
     @staticmethod
     def connect(database: str):
@@ -152,17 +166,17 @@ class Admin:
         Args:
             database (str): the database to connect
         """
-        connector = JINJA_ENV.get_template(POSTGRES_SOURCE_CONNECTOR_TEMPLATE).render(
+        source_connector = JINJA_ENV.get_template(POSTGRES_SOURCE_CONNECTOR_TEMPLATE).render(
             project_db=database,
             postgres_server_name=POSTGRES_SERVER_NAME,
             postgres_port=POSTGRES_PORT,
             postgres_user=POSTGRES_USER,
             postgres_password=POSTGRES_PASSWORD,
-            schemas=",".join([FHIR_DBT_SCHEMA]),
+            fhir_schema=FHIR_DBT_SCHEMA,
         )
         r = requests.post(
             f"{CONNECT_URL}/connectors/",
-            data=connector,
+            data=source_connector,
             headers={"Content-Type": "application/json"},
         )
         r.raise_for_status()
@@ -183,8 +197,9 @@ class Admin:
             host (str): the source server host
             port (int): the source server port
             user (str): a source database user
-            password (:obj:`str`, optional): the user password. If not specified,
-            the command will prompt for a password
+            password (str): the user password. If not specified, \
+the command will prompt for a password. If the password contains a special character, \
+make sure you escape it properly: `--password '"double#escape"'
         """
 
         while not password:
@@ -197,7 +212,6 @@ class Admin:
             user=POSTGRES_USER,
             password=POSTGRES_PASSWORD,
         )
-        conn.autocommit = True
 
         stmt = JINJA_ENV.get_template(f"{type}_fdw.sql.j2").render(
             source_db=source,
@@ -206,7 +220,12 @@ class Admin:
             source_user=user,
             source_password=password,
         )
-        with conn.cursor() as curs:
-            curs.execute(stmt)
 
-        conn.close()
+        try:
+            with conn:
+                with conn.cursor() as curs:
+                    curs.execute(stmt)
+        except Exception as e:
+            log.error(e)
+        finally:
+            conn.close()
